@@ -5,7 +5,7 @@ from Products.Five import BrowserView
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from zope.interface import implements
 from zope.viewlet.interfaces import IViewlet
-
+from zope import component
 
 def compare_dates(a, b):
     return cmp(a.getStartdate(), b.getStartdate())
@@ -231,13 +231,18 @@ class ContractViewlet(Explicit, ContractView):
     implements(IViewlet)
     render = ViewPageTemplateFile('contract.pt')
 
-    def __init__(self, context, request, view, manager):
+    def __init__(self, context, request, view=None, manager=None):
         self.__parent__ = view
         self.context = context
         self.request = request
         self.view = view
         self.manager = manager
 
+        # Attribute used to know which kind of view is displayed.
+        # It can have four values: list, add_contract
+        # add_letter or settings
+        self.view_mode = "list"
+
     def update(self):
         pass
 
@@ -288,3 +293,90 @@ class ContractViewlet(Explicit, ContractView):
                            typ=contract.portal_type.lower())
                 results.append(con)
         return results
+
+    def start_date(self):
+        """ Returns the date when the employee started working.
+        """
+        return self.context.getWorkStartDate()
+
+    def can_create_contract(self):
+        """ This function checks if templates, functions and employment
+        types have already been set. It does not check security.
+        """
+        return bool(self.get_templates()) and \
+               bool(self.get_functions()) and \
+               bool(self.get_employment_types())
+
+    def get_templates(self):
+        """ Returns the list of available templates.
+        """
+        tool = getToolByName(self, 'portal_contracts', None)
+        if tool is None:
+            return []
+        else:
+            return tool.listTemplates()
+
+    def get_functions(self):
+        """Vocabulary for the functions field
+        """
+        tool = getToolByName(self, 'portal_contracts', None)
+        if tool is None:
+            return []
+        else:
+            return tool.getFunctions()
+
+    def get_employment_types(self):
+        """Vocabulary for the employmentType field
+        """
+        tool = getToolByName(self, 'portal_contracts', None)
+        if tool is None:
+            return []
+        else:
+            return tool.getEmploymentTypes()
+
+    def base_contract(self):
+        """Get the current contract of the parent Employee.
+        """
+        view = component.getMultiAdapter((self.context, self.request),
+                                         name=u'contracts')
+        return view.current_contract()
+
+    def default_wage(self):
+        """Get the wage of the parent Employee.
+        """
+        base = self.base_contract()
+        if base is None or base == self:
+            return '0.00'
+        return base.getWage()
+
+    def default_function(self):
+        """Get the function of the parent Employee.
+        """
+        base = self.base_contract()
+        if base is None or base == self:
+            return ''
+        return base.getFunction()
+
+    def default_hours(self):
+        """Get the hours of the parent Employee.
+        """
+        base = self.base_contract()
+        if base is None or base == self:
+            return ''
+        return base.getHours()
+
+    def default_employment_type(self):
+        """Get the employment type of the parent Employee.
+        """
+        base = self.base_contract()
+        if base is None or base == self:
+            return ''
+        return base.getEmploymentType()
+
+    def default_days_per_week(self):
+        """Get the days per week of the parent Employee.
+        """
+        base = self.base_contract()
+        if base is None or base == self:
+            return 0
+        return base.getDaysPerWeek()
