@@ -150,8 +150,9 @@ schema = Schema((
 )
 
 Contract_schema = BaseSchema.copy() + schema.copy()
-Contract_schema['title'].widget.visible = {
-    'view': 'visible', 'edit': 'invisible'}
+# We take the title of the chosen template usually, but this can be
+# overridden by specifically filling in a title.  But at least the
+# title is now not required:
 Contract_schema['title'].required = False
 
 
